@@ -1,7 +1,6 @@
 library(epigrowthfit)
 options(warn = 2L, error = if (interactive()) recover)
-
-o.1 <- egf_cache("egf-1.rds")
+example("egf", package = "epigrowthfit"); o.1 <- m1; o.2 <- m2
 
 
 ## print ###############################################################
